@@ -2,9 +2,9 @@ from infi.pyutils.contexts import contextmanager
 
 
 @contextmanager
-def with_host(host):
+def with_host(client, host):
     from .patches import storagemodel, hbaapi
-    with hbaapi.with_host(host), storagemodel.with_host(host):
+    with hbaapi.with_host(client, host), storagemodel.with_host(client, host):
         yield
 
 
@@ -15,5 +15,5 @@ def install_all_property_collectors_on_client(client):
 
 
 def fetch_all_property_collectors(client):
-    for property_collector in client.facades.values():
-        property_collector.getProperties()
+    for property_collector in client.property_collectors.values():
+        property_collector.get_properties()
